.. include:: ../README.rst
   :end-before: About

.. include:: ../README.rst
   :start-after: =====
   :end-before: Features

Features:

.. include:: ../README.rst
   :start-after: ========
   :end-before: Useful links

API
===

Fixtures
--------
.. automodule:: pytest_reana.fixtures
   :members:

Plugin
------
.. automodule:: pytest_reana.plugin
   :members:

.. include:: ../CHANGES.rst

.. include:: ../CONTRIBUTING.rst


License
=======

.. include:: ../LICENSE

In applying this license, CERN does not waive the privileges and immunities
granted to it by virtue of its status as an Intergovernmental Organization or
submit itself to any jurisdiction.

.. include:: ../AUTHORS.rst
